@@ -27,6 +27,10 @@
 --
 --
 -- $Log: disk_io.c,v $
+-- Revision 1.70  2008/02/06 03:25:58  jsedwards
+-- Added initializer for compressed_file boolean variable so compiler won't
+-- complain about it being uninitialized.
+--
 -- Revision 1.69  2008/02/04 03:10:19  jsedwards
 -- Changed to get backup directory path from user_config.
 --
@@ -580,7 +584,7 @@ void nwos_initialize_disk_io(AccessType type, const char* path)
     uint16 left;
     uint16 right;
     uint16 save;
-    bool compressed_file;
+    bool compressed_file = false;
 #ifndef NO_BACKUP
     const char* backup_dir;
 #endif
